@@ -30,7 +30,7 @@ def phone_number_no_national_prefix(row):
     phone=phone.replace('+34','')
     
     return(phone)
-    
+
 #Direccion completa
 def fake_address(row):
       address = fake.street_address() + ', ' + fake.city()
@@ -115,5 +115,47 @@ def last_name(row):
     last_name = fake.last_name() 
             
     return(last_name)
-    
 
+#Nombre y apellidos pòr separado cuando hay una columna que especifique el sexo
+def gender_HM(row):
+    if row['gender'] == 'M':
+        name_sex = fake.first_name_female()
+    else:
+        name_sex = fake.first_name_male()
+    return name_sex
+
+def gender(row):
+    if row['gender'] == 1:
+        name_sex = fake.first_name_female()
+    else:
+        name_sex = fake.first_name_male()
+    return name_sex
+       
+def gender_MF(row):
+    if row['gender'] == 'F':
+        name_sex = fake.first_name_female()
+    else:
+        name_sex = fake.first_name_male()
+    return name_sex   
+
+#Nombre y apellidos juntos cuando existe una columna de sexo
+def gender_HM(row):
+    if row['gender'] == 'M':
+        name_sex = fake.last_name() + ' ' + fake.last_name() + '; ' + fake.first_name_female()
+    else:
+        name_sex = fake.last_name_male() + ' '+ fake.last_name() + '; '+ fake.first_name_male()
+    return name_sex
+
+def gender(row):
+    if row['gender'] == 1:
+        name_sex = fake.last_name() + ' ' + fake.last_name() + '; ' + fake.first_name_female()
+    else:
+        name_sex = fake.last_name_male() + ' '+ fake.last_name() + '; '+ fake.first_name_male()
+    return name_sex
+       
+def gender_MF(row):
+    if row['gender'] == 'F':
+        name_sex = fake.last_name() + ' ' + fake.last_name() + '; ' + fake.first_name_female()
+    else:
+        name_sex = fake.last_name_male() + ' '+ fake.last_name() + '; '+ fake.first_name_male()
+    return name_sex
\ No newline at end of file
